@@ -228,8 +228,8 @@ class TestNetwork:
         observed_component_vertices = ntw.network_component_vertices
         # known values
         known_component_vertices = {
-            0: [0, 1, 2, 3, 4, 13],
-            1: [5, 6, 7, 8, 9, 10, 11, 12],
+            0: {0, 1, 2, 3, 4, 13},
+            1: {5, 6, 7, 8, 9, 10, 11, 12},
         }
         assert observed_component_vertices == known_component_vertices
 
@@ -464,12 +464,31 @@ class TestNetwork:
         observed_arc_wkt = observed_arc.wkt
         assert observed_arc_wkt == known_arc_wkt
 
+        # See GH#722
+        with pytest.warns(
+            FutureWarning, match="The ``geom_col`` keyword argument is deprecated"
+        ):
+            geom_col = "MY_GEOM"
+            vertices, arcs = spaghetti.element_as_gdf(
+                self.ntw_shp, vertices=True, arcs=True, geom_col=geom_col
+            )
+            assert vertices.geometry.name == geom_col
+            assert arcs.geometry.name == geom_col
+
         # extract only arcs
         arcs = spaghetti.element_as_gdf(self.ntw_shp, arcs=True)
         observed_arc = arcs.loc[(arcs["id"] == (0, 1)), "geometry"].squeeze()
         observed_arc_wkt = observed_arc.wkt
         assert observed_arc_wkt == known_arc_wkt
 
+        # See GH#722
+        with pytest.warns(
+            FutureWarning, match="The ``geom_col`` keyword argument is deprecated"
+        ):
+            geom_col = "MY_GEOM"
+            arcs = spaghetti.element_as_gdf(self.ntw_shp, arcs=True, geom_col=geom_col)
+            assert arcs.geometry.name == geom_col
+
         # extract symmetric routes
         known_length, bounds, h, v = 2.6, (0, 0, 3, 3), 2, 2
         lattice = spaghetti.regular_lattice(bounds, h, nv=v, exterior=False)
@@ -493,9 +512,17 @@ class TestNetwork:
         _, tree = ntw.allneighbordistances(points1, points2, gen_tree=True)
         paths = ntw.shortest_paths(tree, points1, pp_dest=points2)
         paths_gdf = spaghetti.element_as_gdf(ntw, routes=paths)
-        observed_origins = paths_gdf["O"].nunique()
+        observed_origins = paths_gdf["id"].map(lambda x: x[0]).nunique()
         assert observed_origins == known_origins
 
+        # See GH#722
+        with pytest.warns(
+            FutureWarning, match="The ``geom_col`` keyword argument is deprecated"
+        ):
+            geom_col = "MY_GEOM"
+            paths_gdf = spaghetti.element_as_gdf(ntw, routes=paths, geom_col=geom_col)
+            assert paths_gdf.geometry.name == geom_col
+
     def test_regular_lattice(self):
         # 4x4 regular lattice with the exterior
         known = [P00, P10]
@@ -539,7 +566,7 @@ class TestNetworkPointPattern:
         self.OBS = [SCHOOLS, CRIMES]
         self.idxs = ["pp1", "pp2"]
         iterator = zip(self.obs, self.OBS, self.idxs)
-        for (obs, OBS, idx) in iterator:
+        for obs, OBS, idx in iterator:
             self.ntw.snapobservations(OBS, obs, attribute=True)
             setattr(self, idx, self.ntw.pointpatterns[obs])
 
@@ -549,7 +576,7 @@ class TestNetworkPointPattern:
         # known
         cpp = self.ntw.pointpatterns[crimes]
         known_snapped = set(cpp.snapped_coordinates.values())
-        cg_crimes = "cg_%s" % crimes
+        cg_crimes = f"cg_{crimes}"
         # points from pysal geometries
         points = [cg.Point(cpp.points[i]["coordinates"]) for i in cpp.points]
         for dtype in (list, tuple):
@@ -598,9 +625,9 @@ class TestNetworkPointPattern:
 
     @pytest.mark.skipif(GEOPANDAS_EXTINCT, reason="Missing Geopandas")
     def test_pp_from_geopandas(self):
-        idxs = ["gdf_%s" % pp for pp in self.idxs]
+        idxs = [f"gdf_{pp}" for pp in self.idxs]
         iterator = zip(self.obs, self.OBS, idxs)
-        for (obs, OBS, idx) in iterator:
+        for obs, OBS, idx in iterator:
             OBS = geopandas.read_file(OBS)
             kwargs = {"attribute": True}
             if obs == crimes:
